@@ -13,6 +13,7 @@ __license__ = "MIT"
 import sys
 import logging
 import argparse
+import re
 import random
 from collections import defaultdict, namedtuple
 from functools import wraps
@@ -185,7 +186,7 @@ def map_queries(
 
         _map_queries(
             hit_queue, references, queriespath, matespath=matespath,
-            cpu=cpu, blocksize_filtration=blocksize_filtration,
+            cpu=cpu, blocksize_filtration=blocksize_filtration, query_buffersize=query_buffersize,
             blocksize_validation=blocksize_validation, min_score=min_score)
 
         writing_future.result()
@@ -288,7 +289,7 @@ def _map_queries(
                 break
             logging.debug("{} strand of {}".format(
                 "reverse" if refid % 2 else "forward",
-                references.names[refid // 2].decode()))
+                peanut.output.strip_fasta_comment(references.names[refid // 2]).decode()))
             map_to_ref(refid, *ref)
         stats.stop_timer("plain_mapping_running_time")
 
